@@ -28,6 +28,8 @@ our @EXPORT = qw{
 
     do_ruby_hook
 
+    do_python_hook
+
     do_bash_hook
 
     ignore_story_err
@@ -84,9 +86,12 @@ sub set_story {
       $ruby_run_cmd = "ruby -I $dist_lib_dir -r outthentic -I ".story_cache_dir();
     }
 
+    my $python_run_cmd  = "PYTHONPATH=\$PYTHONPATH:".(story_cache_dir()).":$dist_lib_dir python";
 
     get_prop('dsl')->{languages}->{ruby} = $ruby_run_cmd; 
 
+    get_prop('dsl')->{languages}->{python} = $python_run_cmd; 
+
     get_prop('dsl')->{cache_dir} = story_cache_dir();
 
     my $bash_run_opts = "source "._bash_glue_file()." && source $dist_lib_dir/outthentic.bash";
@@ -101,6 +106,8 @@ sub set_story {
 
     _mk_ruby_glue_file();
 
+    _mk_python_glue_file();
+
     _mk_bash_glue_file();
 
 }
@@ -223,6 +230,10 @@ sub _ruby_glue_file {
   story_cache_dir()."/glue.rb";
 }
 
+sub _python_glue_file {
+  story_cache_dir()."/glue.py";
+}
+
 sub _bash_glue_file {
   story_cache_dir()."/glue.bash";
 }
@@ -349,7 +360,7 @@ use strict;
 
 CODE
 
-    close PERL_GLUE,;
+    close PERL_GLUE;
 
 }
 
@@ -393,7 +404,45 @@ sub _mk_ruby_glue_file {
 
 CODE
 
-    close RUBY_GLUE,;
+    close RUBY_GLUE;
+
+}
+
+sub _mk_python_glue_file {
+
+    open PYTHON_GLUE, ">", _python_glue_file() or die $!;
+
+    my $stdout_file = stdout_file();
+    my $test_root_dir = test_root_dir();
+    my $story_dir = get_prop('story_dir');
+    my $project_root_dir = project_root_dir();
+    my $debug_mod12 = debug_mod12();
+
+    my $cache_dir = story_cache_dir;
+
+    print PYTHON_GLUE <<"CODE";
+
+def debug_mod12():
+  return $debug_mod12
+
+def test_root_dir():
+  return '$test_root_dir' 
+
+def project_root_dir():
+  return '$project_root_dir' 
+
+def cache_dir():
+  return '$cache_dir'
+
+def story_dir():
+  return '$story_dir'
+
+def stdout_file():
+  return '$stdout_file' 
+
+CODE
+
+    close PYTHON_GLUE;
 
 }
 
@@ -431,7 +480,7 @@ sub _mk_bash_glue_file {
 
 CODE
 
-    close BASH_GLUE,;
+    close BASH_GLUE;
 
 }
 
@@ -501,6 +550,67 @@ sub do_ruby_hook {
     return 1;
 }
 
+sub do_python_hook {
+
+    my $file = shift;
+
+    my $python_lib_dir = File::ShareDir::dist_dir('Outthentic');
+
+    my $cmd  = "PYTHONPATH=\$PYTHONPATH:".(story_cache_dir()).":$python_lib_dir python $file";
+  
+    if (debug_mod12()){
+        main::note("do_python_hook: $cmd"); 
+    }
+
+
+    my $rand = int(rand(1000));
+
+    my $st = system("$cmd 2>".story_cache_dir()."/$rand.err 1>".story_cache_dir()."/$rand.out");
+
+    if($st != 0){
+      die "do_python_hook failed. \n see ".story_cache_dir()."/$rand.err for details";
+    }
+
+    my $out_file = story_cache_dir()."/$rand.out";
+
+    open PYTHON_HOOK_OUT, $out_file or die "can't open PYTHON_HOOK_OUT file $out_file to read!";
+
+    my @out = <PYTHON_HOOK_OUT>;
+
+    close PYTHON_HOOK_OUT;
+
+    my $story_vars_json;
+
+    for my $l (@out) {
+
+      next if $l=~/#/;
+
+      ignore_story_err($1) if $l=~/ignore_story_err:\s+(\d)/;
+      
+      if ($l=~s/story_var_json_begin.*// .. $l=~s/story_var_json_end.*//){
+        $story_vars_json.=$l;    
+        next;
+      }
+
+
+      if ($l=~/story:\s+(\S+)/){
+
+        my $path = $1;
+
+        if (debug_mod12()){
+            main::note("run downstream story from python hook"); 
+        }
+
+        run_story($path, decode_json($story_vars_json||{}));
+
+        $story_vars_json = undef;
+
+        }
+    }
+
+    return 1;
+}
+
 sub do_bash_hook {
 
     my $file = shift;
@@ -597,7 +707,7 @@ sub story_var {
 
 sub story_vars_pretty {
 
-    join " ", map { "$_:".(story_var($_)) } keys %{get_prop( 'story_vars' ) };
+    join " ", map { "$_:".(story_var($_)) } sort keys %{get_prop( 'story_vars' ) };
 
 }
 
